function [] = main_manual_selection(selection)
% set parameters and decide what to do (if function is run without arguments)
% or perform selected job with selected parameters (given by the arguments)

%% optional arguments
arguments
    selection.pars % optional argument: which parameters? (see list below)
    selection.job % optional argument: which job? (see list below)
end


%% Preparations
if isempty(fieldnames(selection))
    % if function is run by itself: prepare workspace
    disp(datestr(now))
    clear all; clc;
    selection = struct();
end
% close all;
fig = gcf; clf(fig); 
addpath('functions')
addpath('functions/general functions')
addpath('functions/mains')
addpath('functions/plot functions')

%% Choose parameters
if isfield(selection,'pars') == 0
    disp('Choose LLE parameters')
    disp('1: Standard parameters (anomalous dispersion): d = -0.1, f_0 = 2, k_1 = 1, omega = 1')
    disp('2: Standard parameters (omega = 0):            d = -0.1, f_0 = 2, k_1 = 1, omega = 0')
    disp('3: Change standard parameters')
    selection.pars = input('Selection: ');
end
% Set d, f_0, k_1 and omega according to selection
if selection.pars == 1
    pars.d = -0.1; pars.f_0 = 2; pars.k_1 = 1; pars.omega = 1;
elseif selection.pars == 2
    pars.d = -0.1; pars.f_0 = 2; pars.k_1 = 1; pars.omega = 0;
elseif selection.pars == 3
    pars.d = -0.1; pars.f_0 = 2; pars.k_1 = 1; pars.omega = 1;
    disp('Change fields of the pars-structure as desired (by pars.variablename = ...). Then press continue.')
    disp('Current values of the pars-structure:')
    disp(pars)
    keyboard()
else
    error('No valid selection!')
end
% set remaining parameters, create folders
pars = create_pars(pars);


%% Choose desired action
if isfield(selection,'job') == 0
    disp('What do you want to do?')
    disp('1: Path tracing over zeta to find stationary solutions for f_1 = 0')
    disp('2: Path tracing over zeta to find bifurcation branches for f_1 = 0')
    disp('3: Path tracing over f_1 to find traveling wave solutions for one fixed start solution')
    disp('4: Path tracing over f_1 to find traveling wave solutions starting with all constant solutions for one fixed zeta value')
    disp('5: Path tracing over f_1 to find traveling wave solutions for several different (pre defined) zeta-values')
    disp('6: Show all paths (in norm plot)')
    disp('7: Path tracing over f_1 to find traveling wave solutions starting with non-trivial solutions (via pde2path)')
    selection.job = input('Selection: ');
end

switch selection.job
    case 1 % Pfad konstanter Lösungen für f_1 = 0
        addpath('functions\path_tracing zeta')
        start_options.zeta_start = -1;
        start_options.start_direction = 1;
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% Path of constant solutions is computed %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        path_tracing_zeta(start_options,pars,0);
        rmpath('functions\path_tracing zeta')
    case 2 % Alle Verzweigungspfade für f_1 = 0
        addpath('functions\path_tracing zeta')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% Bifurcation paths for f_1 = 0 are computed %%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        while true
            % Load first bifurcation point
            start_options = load_first_bifurcation_point(pars);
            if isempty(start_options)
                disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
                disp('%%%%%%%%%% All bifurcation paths for f_1 = 0 have been computed! %%%%%%%%%%%%%')
                disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
                break
            end
            disp('%%%%%%%%%% Next bifurcation path is computed %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
            % conduct path tracing
            path_tracing_zeta(start_options,pars,1);
            % Delete first bifurcation point
            delete_first_bifurcation_point(pars);
        end
        rmpath('functions\path_tracing zeta')
    case 3
%         opts.zeta = 3; opts.level = 2; % unerwünschte "Flügel" des mittleren Pfades
%         opts.zeta = 3.2; opts.level = 2; % Mitte kommt nicht über Verzweigungspunkt
%         opts.zeta = 2.8; opts.level = 2; % Mitte + Unten nicht ein verbundener Pfad
        opts.zeta = 3.3; opts.level = 3; 
        [bc_mat,f_1] = path_tracing_f_1_fixed_start_solution(opts,pars);
    case 4
        opts.zeta = 4;
        path_tracing_f_1_fixed_zeta(opts,pars);
    case 5
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% Paths of two-mode LLE are computed %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        if selection.pars == 1
            zeta_vec = 2.4:0.2:4.2; % Werte für Fig 2
            zeta_vec = [zeta_vec,2.4:0.1:4.3]; % Werte für Fig 4
%             zeta_vec = [3.1,3.125,3.1344,3.1359,3.15,3.17];
            zeta_vec = [zeta_vec,3.1,3.125,3.1344,3.1359,3.15,3.17]; % Werte für Fig 3
            zeta_vec = unique(zeta_vec);
        else
            zeta_vec = 2.7:0.3:3.9;
        end
        for zeta = zeta_vec
            disp(['%%%%%%%%%% Paths for next zeta-value (zeta = ',num2str(zeta),') are computed %%%%%%%%%%%%%%%%%'])
            opts.zeta = zeta;
            path_tracing_f_1_fixed_zeta(opts,pars);
        end
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% All Paths over f_1 of two-mode LLE (starting %%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% from trivial solutions) have beeen computed  %%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
    case 6
        addpath('functions\plot functions')
        fig = gcf; clf(fig);
        create_norm_plot(pars,[],false,true);
    case 7
        addpath('functions/bifurcation from non trivial solution')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% Paths over f_1 of two-mode LLE (starting from %%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% non-trivial solutions) are now computed       %%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% zeta = 3.6 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        ZetaDreiKommaSechs(pars);
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%% zeta = 3.3 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        ZetaDreiKommaDrei(pars);
        rmpath('functions/bifurcation from non trivial solution')
end

rmpath('functions/mains')

% rmpath(genpath('functions'))
% disp(datestr(now))
