function [bc_mat,f_1] = path_tracing_f_1(bc_mat,zeta,branch,pars)
% Führe Pfadverfolgung nach f_1 durch ausgehend vom Startpunkt
% (bc_mat,zeta). Branch gibt an, welcher der (möglicherweise) verschiedenen
% konstanten Lösung für diesen zeta-Wert als Startpunkt genommen wurde

%% Spezielle Parameterwahl (bei manchen Pfaden nötig)
if (zeta == 3 && strcmp(branch,'mid')) || (zeta == 3.3 && strcmp(branch,'low'))
    disp('Maximale Schrittweite auf 1 reduziert für diesen Pfad')
    temp = pars.lambda_max;
    pars.lambda_max = 1;
elseif (3.1 < zeta) && (zeta <= 3.15)
    temp = pars.lambda_max;
    pars.lambda_max = 1;
end

%% Preparations
f_1 = 0;
% Schrittzähler
k = 0; 
% Erstelle Ordner zur Speicherung des Pfades
[fld,filename_vecs] = create_folder_f_1(zeta,branch,pars);
if exist(filename_vecs,'file')>0
    load(filename_vecs,'path_completed')
    if path_completed
        disp('Path has been computed completely before')
        % Lade alte Ergebnisse
        load(filename_vecs,'point_vecs')
        f_1 = point_vecs.f1s(end);
        k = length(point_vecs.f1s) - 1;
        filename = [fld,'/point_',num2str(k,'%03i'),'_f_1_',num2str(f_1,'%+0.4f'),'.mat'];
        load(filename,'bc_mat')
        handles = initialize_path_tracing_plot('f_1',pars,false,zeta);
        handles = add_point_to_path_plot(handles,point_vecs,'f_1');
        handles = draw_current_solution(handles,bc_mat,pars,false);
        drawnow()
        return
    end
end
% Berechne Start Tangentenvektor und speichere Startpunkt
[tangent_vector,direction] = compute_start_tangent_vector(zeta,bc_mat,pars);
point_vecs = save_new_point_f_1(f_1,zeta,bc_mat,direction,[],filename_vecs,k,fld,pars);
% Initialisiere Plot
handles = initialize_path_tracing_plot('f_1',pars,false,zeta);
handles = add_point_to_path_plot(handles,point_vecs,'f_1');
handles = draw_current_solution(handles,bc_mat,pars,false);
drawnow()

%% Path tracing
continue_tracing = true; % Abbruchkriterium
msg_length = 0; % Um die vorherige Ausgabe im Command Window zu entfernen
lambda = pars.lambda_0_f_1;
while continue_tracing
    k = k + 1;
    %% berechne nächsten Punkt (Prädiktor + Korrrektorschritte)
    % falls man zu nahe an f_1 = 0 landen würde, Schrittweite erhöhen um
    % die Ebene zu überspringen
%     f_1_new = f_1 + lambda * tangent_vector(1);
%     disp(['Erwartetes f_1 :',num2str(f_1_new)])
    if abs(f_1 + lambda * tangent_vector(1)) < 2e-3 && abs(f_1 + 4 * lambda * tangent_vector(1)) > abs(f_1_new)
        lambda = 8*lambda;
%         f_1_new = f_1 + lambda * tangent_vector(1);
%         disp(['Neues erwartetes f_1 :',num2str(f_1_new)])
    end
    [bc_mat_new,f_1_new,tangent_vector_new,corr_steps] ...
        = path_tracing_step_f_1(bc_mat,f_1,zeta,tangent_vector,lambda,direction,pars);

    %% Ebene f_1 = 0 übersprungen?
    if f_1 * f_1_new < 0 % Vorzeichenwechsel in f_1
        disp('Ebene f_1 = 0 erreicht! Punkt auf Ebene wird berechnet.')
        [bc_zero,f1_zero,lambda_total] = ...
            resolve_point_on_f1_zero_plane(bc_mat,f_1,zeta,tangent_vector,direction,pars);
        % Punkt speichern und in Plot ergänzen
        point_vecs = save_new_point_f_1(f1_zero,zeta,bc_zero,direction,...
                                    point_vecs,filename_vecs,k,fld,pars);
        k = k + 1;
        handles = add_point_to_path_plot(handles,point_vecs,'f_1');
        handles = draw_current_solution(handles,bc_zero,pars,false);
        drawnow()
        % Handelt es sich um den gespiegelten Punkt, d.h. ist der Pfad
        % hiermt geschlossen?
        loop_complete = isshifted(bc_zero,pars);
        if loop_complete
            disp('--> Gefundene Lösung entspricht geshifteter Lösung')
            disp('--> Loop vollständig. Pfadverfolgung wird beendet')
            bc_mat = bc_zero; f_1 = f1_zero;
            break
        else
            disp('--> Gefundene Lösung entspricht nicht der geshifteten Lösung')
            disp('--> Pfadverfolgung wird fortgesetzt')
        end
        msg_length = 0;
        % Wähle zum Überspringen des Punktes auf der Ebene f_1 = 0 eine
        % große Schrittweite lambda, um nicht auf dem Shift-Pfad zu landen
%         lambda = pars.lambda_max;
%         [bc_mat_new,f_1_new,tangent_vector_new,corr_steps] ...
%             = path_tracing_step_f_1(bc_mat,f_1,zeta,tangent_vector,lambda,direction,pars);
    end
    
    %% Verzweigungspunkt übersprungen?
    if sum(tangent_vector.*tangent_vector_new)<0
        disp('Verzweigungspunkt/Ebene f_1 = 0 übersprungen!')
    end
    if sum(tangent_vector.*tangent_vector_new)<0 || f_1 * f_1_new < 0
        % Suche besten Tangentenvektor aus (entlang des vorherigen
        % Tangentenvektors bei Verzweigungen oder aus der Ebene f_1 = 0
        % heraus bei Durchlaufen von Punkten mit f_1 = 0)
        [tangent_vector_new,~] ...
            = choose_straight_direction_at_bifurcation_point(tangent_vector,f_1_new,f_1,bc_mat_new,zeta,pars);
        msg_length = 0;
        % In jedem Fall wurde ein Verzweigungspunkt übersprungen 
        % --> VZ WEchsel in direction 
        direction = - direction;
    end

    %% Speichere neuen Punkt
    point_vecs = save_new_point_f_1(f_1_new,zeta,bc_mat_new,direction,...
                                point_vecs,filename_vecs,k,fld,pars);
    
    %% Aktualisiere Daten im Plot
    handles = add_point_to_path_plot(handles,point_vecs,'f_1');
    handles = draw_current_solution(handles,bc_mat_new,pars,false);
    drawnow()

    %% Bereite nächsten Schritt vor
    tangent_vector = tangent_vector_new;
    bc_mat = bc_mat_new; f_1 = f_1_new;
    
    %% Adaptive Schrittweitensteuerung
    [lambda,steplength_string] = adapt_predictor_steplength(lambda,pars,corr_steps,f_1,tangent_vector);

    %% Berichte über Status
    msg = [num2str(k),'-ten Punkt auf Pfad berechnet, f_1 = ',num2str(f_1_new),...
           ', ',num2str(corr_steps),' Korrektorschritte, ',steplength_string,'\n'];
    fprintf([ repmat(sprintf('\b'), 1, msg_length-1) , msg ]); % Löscht vorherige Nachricht und gibt neue aus
    if mod(k,25)==0
        msg_length = 0; % Alle 25 Schritte Ergebnisse in neue Zeile schreiben
    else
        msg_length = length(msg);
    end

    %% Abbruch falls f_1 zu groß, sonst weiter rechnen
    if f_1 > 7
        continue_tracing = false;
    end
end

if zeta == 3 && strcmp(branch,'mid')
    pars.lambda_max = temp;
end

% path has been computed completely --> update the variable path_completed
path_completed = true;
save(filename_vecs,'point_vecs','path_completed')

disp('Path computed completely')


end

