function [zeta,bc_mat,direction,tangent_vector] = find_start_solution(start_options,b0,c0,pars)
% Wende fsolve zur Berechnung einer Startfunktionen für die Pfadverfolgung 
% der Ein-Moden-LLE an (d.h. zur Berechnung einer Nullstelle von H bei
% fixem Parameter zeta)

M = pars.M_zeta;
zeta = start_options.zeta_start;

% Funktion H_tilde: Funktion H, bei der nur die Funktionswerte (bvec,cvec) an den
% Stützstellen x_2,...,x_N-1 die Variablen sind, während zeta fest ist.
% Dabei wird omega unabhängig vom eigentlichen Wert auf Null gesetzt, damit
% fsolve eine konstante Lösung findet 
omega_temp = 0;
H_tilde = @(bc_mat) H_tilde_values_and_jacobian(pars.f_1,bc_mat,zeta,pars.d,pars.f_0,pars.k_1,omega_temp,pars.h,M,pars.x_short);

% Startvektor für fsolve
bc_mat=[ b0*ones(M-1,1) , c0*ones(M-1,1) ];

%Löse H_tilde(b,c)=0 ausgehend vom Startvektor bc_mat. 
options = optimoptions('fsolve','SpecifyObjectiveGradient',true);
bc_mat = fsolve(H_tilde,bc_mat,options);

% Tangentenvektor im Startpunkt
direction=1; % gibt an, ob der Tangentialvektor in die Richtung zeigt, in der
% die Determinante der erweiterten Matrix positiv ist oder negativ
tangent_vector = calculate_tangent_vector(pars.f_1,bc_mat,zeta,pars.d,pars.f_0,pars.k_1,pars.omega,pars.h,M,pars.x_short,direction,0);
% im ersten Schritt soll zeta kleiner oder größer werden?
if sign(tangent_vector(1)) ~= start_options.start_direction
    tangent_vector = -tangent_vector;
    direction=-direction;
end

end

