function [indices,indices_plot,norms,handle_desired_zeta] = look_for_solutions(zeta,pars)
% Markiere alle Punkte, die Lösungen für den gesuchten zeta-Wert
% entsprechen

ms = 8; % MarkerSize

% Lade point_vecs des Pfades konstanter Lösungen
fld = [pars.fld,'/path_one_mode_constant_solutions'];
load([fld,'/point_vecs.mat'],'point_vecs')

% Suche nach passenden Indizes (d.h. suche den ersten von zwei benachbarten 
% Indizes, bei denen ein zugehöriger zeta Wert größer und einer kleiner als
% das gesuchte zeta ist):
indices = find( ( (point_vecs.zetas(2:end)-zeta) .* (point_vecs.zetas(1:end-1)-zeta) ) < 0 );
% Das gesuchte zeta befindet sich dann kurz nach den Punkten, die durch
% indices gegeben sind.

% Indizes, mit denen der zeta Wert am genausten getroffen wird
indices_plot = indices;
for ind = 1:length(indices_plot)
    index = indices_plot(ind);
    if abs(point_vecs.zetas(index)-zeta) > abs(point_vecs.zetas(index+1)-zeta)
        indices_plot(ind) = index + 1;
    end
end

% markiere alle gefundenen Punkte
zetas = point_vecs.zetas(indices_plot);
norms = point_vecs.norms(indices_plot);
f1s = point_vecs.f1s(indices_plot);
handle_desired_zeta = plot3(zetas,f1s,norms,'o','Color','cyan','MarkerFaceColor','cyan','MarkerSize',ms,'DisplayName','solutions with desired \zeta');
drawnow()

% Indizes nach Größe der Norm der Lösungen sortieren:
[~,sorting_indices] = sort(point_vecs.norms(indices_plot),'descend');
indices = indices(sorting_indices); 
indices_plot = indices_plot(sorting_indices); 

end
