function [bc_mat,zeta,lambda_total,k,point_vecs,handles] = ...
    resolve_bifurcation_point(bc_mat,zeta,tangent_vector,lambda,direction,k,branch,point_vecs,filename_vecs,fld,pars,handles)
% Im nächsten Pfadverfolgungsschritt ausgehend vom Punkt in bc_mat mit
% Schrittweite lambda wird ein Verzweigungspunkt übersprungen. Löse ihn
% auf, indem die Schrittweite lambda nach jedem Schritt halbiert wird

% Hintergrund: Falls der Verzeiwgungspunkt übersprungen wird, zeigt der
% neue Tangentenvektor in entgegengesetzte Richtung. Mit halber
% Schrittweite geht man ihm also in Rückrichtung entgegen.
% Falls er nicht übersprungen wird, rückt man schrittweise näher ran.
lambda = lambda/2;
[bc_mat_new,zeta_new,tangent_vector_new] ...
    = path_tracing_step(bc_mat,zeta,tangent_vector,lambda,direction,pars);

lambda_total = 0;
while lambda > 1e-5
    if sum(tangent_vector.*tangent_vector_new)<0
        % Verwerfe neu berechneten Punkt, probiere es stattdessen mit
        % lambda/2 nochmal
        lambda = lambda/2;
        [bc_mat_new,zeta_new,tangent_vector_new] ...
            = path_tracing_step(bc_mat,zeta,tangent_vector,lambda,direction,pars);
        %disp('Schrittweite zu groß (Verzweigungspunkt wird übersprungen)')
        %disp(['Halbiere Schrittweite zu ',num2str(lambda)])
    else
        % Übernehme neu berechneten Punkt, gehe von ihm aus mit halber
        % Schrittweite näher zum Verzweigungspunkt
        bc_mat = bc_mat_new; zeta = zeta_new; 
        % speichere neuen Punkt als Punkt des Pfades
        [point_vecs] = save_new_point(zeta,bc_mat,direction,...
                                       point_vecs,filename_vecs,...
                                       k,branch,fld,pars);
        % Ergänze Punkt im Plot des Pfades
        handles = add_point_to_path_plot(handles,point_vecs,'zeta');
        handles = draw_current_solution(handles,bc_mat,pars,true);
        drawnow()        
        % Bereite nächsten Schritt vor
        tangent_vector = tangent_vector_new;
        lambda_total = lambda_total + lambda;
        k = k+1;
        lambda = lambda/2;
        % Führe nächsten Schritt durch
        [bc_mat_new,zeta_new,tangent_vector_new] ...
            = path_tracing_step(bc_mat,zeta,tangent_vector,lambda,direction,pars);
        %disp('Neue Näherung an den Verzweigungspunkt berechnet.')
        %disp(['Neue Totalvariation ',num2str(total_variation(bc_mat)),...
        %      ', neue Schrittweite ',num2str(lambda)])
    end
end

disp(['Verzweigungspunkt wurde aufgelöst. Gesamtschrittweite zum Verzweigungspunkt: ',...
      num2str(lambda_total)])

end

