function [bifurcation_points,bifurcation_points_todo] = ...
            save_new_bifurcation_point(zeta_bifur,bc_bifur,level,zeta,bc_mat,...
                bifurcation_points,bifurcation_points_todo,...
                filename_bifur,filename_bifur_todo,pars,bifurcation_mode)
% Add a new bifurcation point of the path to the bifurcation_points 
% structures

%% Structure aller Verzweigungspunkte
bifurcation_points.zetas(end+1) = zeta_bifur;
bifurcation_points.f1s(end+1) = 0;
bifurcation_points.norms(end+1) = func_norm(bc_bifur,pars.h).^2;
bifurcation_points.b_values(:,end+1) = bc_bifur(:,1);
bifurcation_points.c_values(:,end+1) = bc_bifur(:,2);
bifurcation_points.levels(end+1) = level+1;

save(filename_bifur,'bifurcation_points')

%% Structure aller Verzweigungspunkte, die weiter betrachtet werden müssen
bifurcation_points_todo.zetas(end+1) = zeta_bifur;
bifurcation_points_todo.f1s(end+1) = 0;
bifurcation_points_todo.norms(end+1) = func_norm(bc_bifur,pars.h).^2;
bifurcation_points_todo.b_values(:,end+1) = bc_bifur(:,1);
bifurcation_points_todo.c_values(:,end+1) = bc_bifur(:,2);
bifurcation_points_todo.levels(end+1) = level+1;

%% Welche Tangentenvektoren kommen für weitere Verzweigungen in Frage?
M = pars.M_zeta;
tangent_vector_mat = zeros([2*M-1,4]);
directions = [1,1,-1,-1];
% Berechne alle Tangentenvektoren
direction = 1;
tangent_vector_mat(:,1) = calculate_tangent_vector(pars.f_1,bc_bifur,zeta_bifur,pars.d,pars.f_0,pars.k_1,pars.omega,pars.h,M,pars.x_short,direction,0);
tangent_vector_mat(:,2) = calculate_tangent_vector(pars.f_1,bc_bifur,zeta_bifur,pars.d,pars.f_0,pars.k_1,pars.omega,pars.h,M,pars.x_short,direction,1);
tangent_vector_mat(:,3:4) = -tangent_vector_mat(:,1:2);
% Überprüfe, welche der Tangentenvektoren entlang der Richtung des Punktes 
% zeigt, von dem man auf den Verzweigungspunkt gestoßen ist
oncoming_direction = [zeta-zeta_bifur;bc_mat(:,1)-bc_bifur(:,1);...
                                      bc_mat(:,2)-bc_bifur(:,2)];

inds = true(1,4);
valid_tangent_vectors = {};
for ind = 1:4
    u = oncoming_direction; v = tangent_vector_mat(:,ind);
    % Vektor zwischen tangent_vector und oncoming direction
    angle = acos(dot( u/norm(u) , v/norm(v) ));
    if bifurcation_mode == 0
        % Bei der Berechnung eines Pfades konstanter Lösungen wird die
        % Fortsetzungs-Richtung automatisch berechnet, braucht also nicht
        % zu den zu erledigenden Tangentenvektoren aufgenommen werden.
        if angle < pi/8 || angle > 7*pi/8 % quasi dieselbe Richtung (Winkel kleiner 22.5°)
            inds(ind) = false; % Dieser Tangentenvektor wird nicht übernommen!
%             disp(['Winkel ',num2str(ind),': ',num2str(angle/pi*180),'° --> Richtung wird gestrichen.'])
            continue
        end
    else
        if angle < pi/8 % quasi dieselbe Richtung (Winkel kleiner 22.5°)
            inds(ind) = 0; % Dieser Tangentenvektor wird nicht übernommen!
%             disp(['Winkel ',num2str(ind),': ',num2str(angle/pi*180),'° --> Richtung wird gestrichen.'])
            continue
        end
    end
%     disp(['Winkel ',num2str(ind),': ',num2str(angle/pi*180),'°'])
    % Tangentenvektor in zu erledigende Tangentenvektoren übernehmen
    valid_tangent_vectors{end+1} = tangent_vector_mat(:,ind);
end

bifurcation_points_todo.num_possible_directions(end+1) = sum(inds);
bifurcation_points_todo.tangent_vectors{end+1} = valid_tangent_vectors;
bifurcation_points_todo.tangent_directions{end+1} = directions(inds);

disp([num2str(sum(inds)),' mögliche Verzweigungsrichtungen werden für später gespeichert.'])

save(filename_bifur_todo,'bifurcation_points_todo')

end

