function [success,direction] ...
    = try_bifurcation(tangent_vector,bc_mat,zeta,direction,pars)
% Teste, ob man mit den angegebenen Daten auf einen Verzweigungspfad stößt,
% d.h. 
% 1.) weg vom Anfangspunkt kommt und 
% 2.) nicht wieder auf einer konstanten Lösung (Totalvariation = 0) landet und
% 3.) die Tangentenvektoren der neu berechneten Punkte in ungefähr dieselbe
% Richtung zeigen

% Dazu werden zwei Schritte der Pfadverfolgung gemacht. Nach dem ersten
% Schritt muss der Tangentenvektor evtl. noch umgedreht werden, falls der
% Wert von direction noch nicht korrekt ist

lambda = pars.lambda_0;

%% Schritt 1
[bc_mat_new,zeta_new,tangent_vector_new] ...
    = path_tracing_step(bc_mat,zeta,tangent_vector,lambda,direction,pars);
% Abstand zum Ausgangspunkt checken
diff = func_norm(bc_mat_new-bc_mat,pars.h);
if diff < 1e-3
    disp(['Abstand zu Ausgangspunkt nach einem Schritt: ',num2str(diff)])
    disp('--> Zu klein, angegebener Tangentenvektor führt zu nichts!')
    success = false;
    return
end
% Totalvariation checken
tv = total_variation(bc_mat_new);
if tv < 1e-3
    disp(['Totalvariation nach einem Schritt: ',num2str(tv)])
    disp('--> Zu gering, angegebener Tangentenvektor führt zu nichts!')
    success = false;
    return
end
% Winkel des nächsten Tangentenvektors zu Start-Tangentenvektor
u = tangent_vector; v = tangent_vector_new;
angle = acos(dot( u/norm(u) , v/norm(v) ));
if (angle > pi/4) && (pi - angle > pi/4)
    disp(['Winkel zwischen ersten beiden Tangentenvektoren: ',num2str(angle/pi*180),'°'])
    disp('--> Richtungen passen nicht zusammen, angegebener Tangentenvektor führt zu nichts!')
    success = false;
    return
end
% Falls entgegengesetzte Richtung: Vektor umkehren, direction umändern
if angle>pi/2
    % disp('Zweiter Tangentenvektor wird umgedreht')
    tangent_vector_new = - tangent_vector_new;
    direction = - direction;
    angle = pi - pi/2;
end

%% Schritt 2:
[bc_mat_new_new,zeta_new_new,tangent_vector_new_new] ...
    = path_tracing_step(bc_mat_new,zeta_new,tangent_vector_new,lambda,direction,pars);
% Abstand zum Ausgangspunkt checken
diff = func_norm(bc_mat_new_new-bc_mat,pars.h);
if diff < 1e-3
    disp(['Abstand zu Ausgangspunkt nach zwei Schritten: ',num2str(diff)])
    disp('--> Zu klein, angegebener Tangentenvektor führt zu nichts!')
    success = false;
    return
end
% Totalvariation checken
tv = total_variation(bc_mat_new_new);
if tv < 1e-3
    disp(['Totalvariation nach zwei Schritten: ',num2str(tv)])
    disp('--> Zu gering, angegebener Tangentenvektor führt zu nichts!')
    success = false;
    return
end
% Winkel des nächsten Tangentenvektors zu vorherigem Tangentenvektor
u = tangent_vector_new; v = tangent_vector_new_new;
angle = acos(dot( u/norm(u) , v/norm(v) ));
if angle > pi/4
    disp(['Winkel zwischen zweitem und drittem Tangentenvektoren: ',num2str(angle/pi*180),'°'])
    disp('--> Richtungen passen nicht zusammen, angegebener Tangentenvektor führt zu nichts!')
    success = false;
    return
end

%% Alle Prüfungen überstanden
disp('Angegebener Tangentenvektor führt auf neuen Pfad! Berechnung wird gestartet')
success = true;

end