function [handles] = create_norm_plot(pars,active_path_tracing,view2D,zoom,zeta_vec)

% active_path_tracing = 'zeta'/'f_1' --> add an empty path that is 
% currently traced plus the bifurcation points found on it
% active_path_tracing = [] --> no current path/bifurcation points

% If active_path_tracing = 'zeta' or []:
%   zoom can be true or false and determines, if only the region between
%   the turning points is shown
% If active_path_tracing = 'f_1'
%   zoom can be true or false as before, or it can contain a zeta-value,
%   for which the path tracing is conducted and which is supposed to be
%   zoomed on

% With the optional argument zeta_vec, one can determine if only the paths 
% of the two-mode LLE for the zeta values given in zeta_vec are supposed 
% to be shown.

gray = [.4 .4 .4];
brown = [0.6 0.3 0];
lwd = 1.5; % LineWidth
ms = 7; % MarkerSize
handles.paths_one_mode = gobjects(0);
handles.paths_two_mode = gobjects(0);

first_primary_bifur = true;
first_secondary_bifur = true;
first_bifurcation_points = true;

% Check for existing paths
files = dir(pars.fld);
% Plot all relevant paths
for ind = 1:length(files)
    name = files(ind).name;
    % Pfad konstanter Lösungen der Ein-Moden-LLE
    if strcmp(name,'path_one_mode_constant_solutions')
        % Pfad
        filename = [pars.fld,'/',name,'/point_vecs.mat'];
        if exist(filename,'file')>0
            load(filename)
            handles.path_one_mode_const ...
                = plot3(point_vecs.zetas,0*point_vecs.zetas,point_vecs.norms, ...
                'k','DisplayName','f_1=0, const. solutions','LineWidth',lwd);
                set(gca,'ColorOrderIndex',max(get(gca,'ColorOrderIndex')-1,1));
            hold on
        end
    % Primäre Verzweigungspfade der Ein-Moden-LLE
    elseif ( (length(name)>=33) && strcmp(name(1:33),'path_one_mode_primary_bifurcation') ) || (length(name)>=25) && strcmp(name(1:25),'path_one_mode_bifurcation')
        % Pfad
        filename = [pars.fld,'/',name,'/point_vecs.mat'];
        if exist(filename,'file')>0
            load(filename)
            handles.paths_one_mode(end+1) ...
                = plot3(point_vecs.zetas,0*point_vecs.zetas,point_vecs.norms,...
                'Color',gray,'LineWidth',lwd);
            set(gca,'ColorOrderIndex',get(gca,'ColorOrderIndex')-1);
            if first_primary_bifur
                set(handles.paths_one_mode(end),'DisplayName','f_1=0, primary bifurcations')
                first_primary_bifur = false;
            else
                set(handles.paths_one_mode(end),'HandleVisibility','off')
            end
            hold on
        end
    % Sekundäre Verzweigungspfade der Ein-Moden-LLE
    elseif (length(name)>=35) && strcmp(name(1:35),'path_one_mode_secondary_bifurcation')
        % Pfad
        filename = [pars.fld,'/',name,'/point_vecs.mat'];
        if exist(filename,'file')>0
            load(filename)
            handles.paths_one_mode(end+1) ...
                = plot3(point_vecs.zetas,0*point_vecs.zetas,point_vecs.norms,...
                'Color',brown,'LineWidth',lwd);
            set(gca,'ColorOrderIndex',get(gca,'ColorOrderIndex')-1);
            if first_secondary_bifur
                set(handles.paths_one_mode(end),'DisplayName','f_1=0, secondary bifurcations')
                first_secondary_bifur = false;
            else
                set(handles.paths_one_mode(end),'HandleVisibility','off')
            end
            hold on
        end
    % Verzweigungspunkte
    elseif strcmp(name,'bifurcation_points.mat')
        load([pars.fld,'/',name])
        handles.bifurcation_points ...
            = plot3(bifurcation_points.zetas,0*bifurcation_points.zetas,...
                    bifurcation_points.norms,'o','MarkerFaceColor',gray,...
                    'MarkerEdgeColor',gray,'MarkerSize',ms);
        if first_bifurcation_points && length(bifurcation_points.norms)>0
            set(handles.bifurcation_points,'DisplayName','bifurcation points')
            first_bifurcation_points = false;
        else
            set(handles.bifurcation_points,'HandleVisibility','off')
        end
        set(gca,'ColorOrderIndex',max(get(gca,'ColorOrderIndex')-1,1));
        hold on
    % Pfade der Zwei-Moden-LLE
    elseif (length(name)>=18) && strcmp(name(1:18),'path_two_mode_zeta')
        filename = [pars.fld,'/',name,'/point_vecs.mat'];
        zeta = str2double(name(20:28));
        if exist('zeta_vec','var') == 0 || any(abs(zeta - zeta_vec)<1e-15)
            if exist(filename,'file')>0
                load(filename)
                % Special Lösung anders plotten (Symmetrie-Teile nicht
                % verbinden)
                if strcmp(name(end-6:end),'special')
                    f1s = point_vecs.f1s;
                    norms = point_vecs.norms;
                    handles.paths_two_mode(end+1) ...
                        = plot3(zeta + 0*f1s,f1s,norms,...
                        'DisplayName',['\zeta = ',num2str(zeta)],...
                        'LineWidth',lwd);
                    hold on
                    set(gca,'ColorOrderIndex',get(gca,'ColorOrderIndex')-1);
                    f1s = -point_vecs.f1s(end:-1:1);
                    norms = point_vecs.norms(end:-1:1);
                    handles.paths_two_mode(end+1) ...
                        = plot3(zeta + 0*f1s,f1s,norms,...
                        'HandleVisibility','off',...
                        'LineWidth',lwd);
                elseif length(name)>=39 && strcmp(name(30:39),'nontrivial') && zeta == 3.6
                    % diese Pfade werden gar nicht gespiegelt
                    f1s = point_vecs.f1s;
                    norms = point_vecs.norms;
                    handles.paths_two_mode(end+1) ...
                        = plot3(zeta + 0*f1s,f1s,norms,...
                        'DisplayName',['\zeta = ',num2str(zeta)],...
                        'LineWidth',lwd);
                    hold on
                else
                    f1s = [-point_vecs.f1s(end:-1:2),point_vecs.f1s];
                    norms = [point_vecs.norms(end:-1:2),point_vecs.norms];
                    if zeta == 3.3 && get(gca,'ColorOrderIndex') == 5 % nicht Farbe grün verwenden für zeta = 3.3
                        set(gca,'ColorOrderIndex',get(gca,'ColorOrderIndex')+1)
                    end
                    handles.paths_two_mode(end+1) ...
                        = plot3(zeta + 0*f1s,f1s,norms,...
                        'DisplayName',['\zeta = ',num2str(zeta)],...
                        'LineWidth',lwd);
                    if length(name)>=39 && strcmp(name(30:39),'nontrivial') && zeta == 3.3
                        % Pfad ab nichttrivialer Lsg für zeta = 3.3 ist auf 
                        % zwei Ordner aufgeteilt. Beide sollen in der selben
                        % Farbe (grün) dargestellt werden (incl. gespiegeltem Teil)
                        handles.paths_two_mode(end).Color = [0.39 0.83 0.07];
                        if name(end) == '2'
                            % zweiten Teilpfad nicht in Legende anzeigen
                            handles.paths_two_mode(end).HandleVisibility = 'off';
                        end
                    end
                    hold on
                end
            end
        end
    end
end

if isempty(active_path_tracing) == 0 % Pfadverfolgung aktiv
    % Aktueller Punkt der Pfadverfolgung
    handles.curr_solution_marker ...
        = plot3(NaN,NaN,NaN,'ro','DisplayName','current solution',...
                'MarkerFaceColor','r','MarkerEdgeColor','r','MarkerSize',ms);
    hold on
    % Aktueller Pfad
    handles.curr_path ...
        = plot3(NaN,NaN,NaN,'r','DisplayName','current path',...
        'LineWidth',lwd);
    % Verzweigungspunkte
    handles.curr_bifurcations ...
        = plot3(NaN,NaN,NaN,'o','MarkerFaceColor',gray,'MarkerEdgeColor',gray,...
                'MarkerSize',ms);
    if first_bifurcation_points
        set(handles.curr_bifurcations,'DisplayName','bifurcation points')
        first_bifurcation_points = false;
    else
        set(handles.curr_bifurcations,'HandleVisibility','off')
    end
end

% Weitere Plot Einstellungen
xlabel('$\zeta$','Interpreter','latex'); xlim([-1,7]);
ylabel('$f_1$','Interpreter','latex'); ylim([-4,4]);
zlabel('$\frac{1}{2\pi} ||u||_2^2$','Interpreter','latex'); zlim([0,4]);
title('Overview of all paths')

legend('location','northeastoutside')
grid on

if view2D
    view(0,0)
else
    if strcmp(active_path_tracing,'f_1')  && zoom ~= false && zoom ~= true
        % falls wir im Zoom Modus sind: f_1 - norm - Ebene etwas besser
        % darstellen
        view(75,10)
    else
        view(37.5,30)
    end
end

if strcmp(active_path_tracing,'zeta') && zoom == true
    xlim([2.7,4.1])
elseif strcmp(active_path_tracing,'f_1')
    if zoom == true
        % zoom on area between turning points
        xlim([2.7,4.1])
    elseif zoom == false
        % do not change limits
    else
        % zoom around zeta-value given by zoom
        xlim([zoom-0.25,zoom+0.25])
    end
elseif isempty(active_path_tracing) %|| sum(active_path_tracing == false)
    if zoom
        % zoom on area between turning points
        xlim([2.7,4.1])
    end
end

end

