clear variables; %clc; 
close all;
disp(datestr(now))
addpath('functions')

%% Select figure/parameters
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%%%%%% Choose desired figures %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('1: Figure 1       (runtime ~1 sec)')
disp('2: Figure 2/3/4   (standard parameters d = -0.1, f_0 = 2, k_1 = 1, omega = 1, runtime ~2 hours)')
disp('3: Figure 5       (runtime ~1 sec)')
disp('4: Figure 6/7/8/9 (standard parameters with omega = 0, runtime ~1 hour)')
selection = input('Selection: ');

% Figure 1 or 5?
if selection == 1
    run('functions/figure creation/Figure1.m')
    return
elseif selection == 3
    run('functions/figure creation/Figure5.m')
    return
end

% Otherwise: Choose right parameters, do computations
if selection == 2
    selection_pars = 1;
elseif selection == 4
    selection_pars = 2;
end

% Expected duration, pde2path warning
if selection_pars == 1
    disp('All data for this parameter regime is computed. This takes around two hours.')
elseif selection_pars == 2
    disp('All data for this parameter regime is computed. This takes around one hour.')
    warning(['For some of the following paths, pde2path is required. Make sure you have ',...
             'got it set up. Further, the success of some path tracings depends on the ',...
             'version of pde2path (version 2.7 or 2.8 is required). You can check your ',...
             'version in the setpde2path-file of your pde2path installation'])
    input('To continue, press ''Enter'' ')
else
    error('Invalid selection')
end

%% Computations
% Compute path of stationary solutions for f_1 = 0
main_manual_selection("pars",selection_pars,"job",1)

% Compute path of bifurcation branches for f_1 = 0
main_manual_selection("pars",selection_pars,"job",2)

% Path tracing over f_1 to find traveling wave solutions for several different (pre defined) zeta-values
main_manual_selection("pars",selection_pars,"job",5)

% Display Norm-Plot of all computed paths
main_manual_selection("pars",selection_pars,"job",6)

% Path tracing over f_1 to find traveling wave solutions starting from a non-tivial solution for f_1 = 0
if selection_pars == 2
    figure
    main_manual_selection("pars",selection_pars,"job",7)
end

% Computation of data done
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%%%%%% All data has been computed. Figures are now created %%%%%%%%%%%%%%%%%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')

% Display Norm-Plot of all computed paths
close all
main_manual_selection("pars",selection_pars,"job",6)

%% Create all Figures
close all
addpath('functions/figure creation/')
addpath('functions/general functions')
addpath('functions/plot functions')
if selection_pars == 1
    pars.d = -0.1; pars.f_0 = 2; pars.k_1 = 1; pars.omega = 1;
    pars = create_pars(pars);
    % Figure 2
    figure2(pars);

    % Figure 3
    figure3(pars)    
    
    % Figure 4
    figure4(pars)

elseif selection_pars == 2
    pars.d = -0.1; pars.f_0 = 2; pars.k_1 = 1; pars.omega = 0;
    pars = create_pars(pars);
    % Figure 6
    figure6(pars)

    % Figure 7
    figure7(pars)

    % Figure 8
    figure8(pars)

    % Figure 9
    figure9(pars)

end

%%
disp('All done!')
disp(datestr(now))
